#
# spec file for package python-guidata
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_with     test
Name:           python-guidata
Version:        1.7.6
Release:        1.1
License:        CECILL-2.0
Summary:        Generat GUIs for easy dataset editing and display 
Url:            https://github.com/PierreRaybaut/guidata
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/g/guidata/guidata-%{version}.zip
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
%if %{with test}
BuildRequires:  %{python_module pytest}
%endif
Requires:       python-qt5
Recommends:     python-h5py
Recommends:     spyder
BuildArch:      noarch

%python_subpackages

%description
Based on the Qt Python binding module PyQt5, guidata is a Python
library generating graphical user interfaces for easy dataset editing
and display. It also provides helpers and application development 
tools for PyQt5.

PyQt4 and pyside are also supported.

%prep
%setup -q -n guidata-%{version}
# Fix wrong file end-of-line encoding
sed -i 's/\r$//' CHANGELOG.md
sed -i 's/\r$//' Licence_CeCILL_V2-en.txt
sed -i 's/\r$//' README.md

%build
%python_build

%install
%python_install
%{python_expand sed -i 's/\r//' %{buildroot}%{$python_sitelib}/guidata/userconfig.py
chmod +x %{buildroot}%{$python_sitelib}/guidata/userconfig.py
sed -i "s|^#!/usr/bin/env python$|#!%__$python|" %{buildroot}%{$python_sitelib}/guidata/userconfig.py
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/guidata/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/guidata/
%fdupes %{buildroot}%{$python_sitelib}
}
rm %{buildroot}%{_bindir}/guidata-tests-py*

%if %{with test}
%check
%python_exec setup.py test
%endif


%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGELOG.md Licence_CeCILL_V2-en.txt README.md
%{python_sitelib}/guidata/
%{python_sitelib}/guidata-%{version}-py*.egg-info

%changelog
* Fri Aug 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 1.7.6
  * Fixed Spyder v3.0 compatibility issues.
* Fri Jan 29 2016 toddrme2178@gmail.com
- Don't require python-qt5 on older releases that don't have it.
* Fri Jan 29 2016 toddrme2178@gmail.com
- Update to version 1.7.5
  + Bug fixes:
  * `FilesOpenItem.check_value` : if value is None, return False (avoids "None Type object is not iterable" error)
- Update to version Version 1.7.4
  + Bug fixes:
  * Fixed compatibility issue with Python 3.5.1rc1 (Issue #32: RecursionError in `userconfig.UserConfig.get`)
  * `HDF5Reader.read_object_list`: fixed division by zero (when count was 1)
  * `hdf5io`: fixed Python3 compatibility issue with unicode_hdf type converter
- Update to version 1.7.3
  + Features:
  * Added CHM documentation to wheel package
  * hdf5io: added support for a progress bar callback in "read_object_list" (this allows implementing a progress dialog widget showing the progress when reading an object list in an HDF5 file)
  + Bug fixes:
  * Python 3 compatibility: fixed `hdf5io.HDF5Writer.write_object_list` method
  * data items:
    > StringItem: when `notempty` parameter was set to True, item value was not checked at startup (expected orange background)
  * disthelpers:
    > Supporting recent versions of SciPy, h5py and IPython
    > Fixed compatibility issue (workaround) with IPython on Python 2.7 (that is the "collection.sys cx_Freeze error")
- Update to version 1.7.2
  + Bug fixes:
  * Fixed compatibility issues with old versions of Spyder (<v2.3)
- Update to version 1.7.1
  + Bug fixes:
  * Fixed Issue #25: ConfigParser.get unexpected keyword argument 'raw'
  * Fixed tests failures: disthelpers, guiqwt/tests/loadsaveitems_hdf5.py
  + Features:
  * userconfigio: added support for serializing/deserializing NumPy scalars
  * Fixed Issue #47: added support for DateTimeItem/DateItem (de)serialization
  + Setup:
  * Using setuptools "entry_points" instead of distutils "scripts"
- Update to version Version 1.7.0
  + Possible API compatibility issues:
  * Added support for PyQt5 (removed old-style signals)
* Thu Oct 17 2013 toddrme2178@gmail.com
- Add python-Cython Requires and BuildRequires needed by python-guiqwt
* Tue Oct 15 2013 toddrme2178@gmail.com
- Update to 1.6.1
  * disthelpers:
  * Changed arguments from "architecture=None, python_version=None" to "msvc_version, architecture=None"
- Update to 1.6.0
  * Added support for Python 3 (see module `guidata.py3compat`).
  * disthelpers:
  * Added support for Python 3.3
  * Added support for pygments (and partial support for zmq: still failing)
  * FloatArrayItem: added support for `unit` property value
  * disthelpers.prepend_module_to_path: unload modules which were already imported to be able to replace them by other versions (mostly `guidata` should be concerned by this if the function is used -as it should be- in package's __init__.py script)
* Sat Apr 13 2013 toddrme2178@gmail.com
- Added pyside support
- Remove sles workarounds since it doesn't work with sles anyway
- Update to 1.5.1
  * New features
  * HDF5 serialization (HDF5 reader/writer):
  * Added context manager
  * Added convenience methods `read` and `write`
  * Added convenience methods `write_object_list` and `read_object_list` to save/restore objects implementing DataSet-like `serialize` and `deserialize` methods
  * Datasets I/O (HDF5/ini): None values (unset items) can now be saved/loaded for FloatItem, IntItem and BoolItem objects
  * disthelpers: added option 'exclude_dirs' to 'add_module_data_files' and 'add_module_data_dir' methods
  * Added slider support for FloatItem objects (contributor: julien.jaeck)
  * (Issue 21) Added option 'size' in dataset `edit` and `view` methods to resize the generated dialog box (size may be a tuple of integers (width, height) or a QSize object)
  * Possible API compatibility issues
  * guidata now requires Python 2.6 (Python 2.5 support has been dropped)
  * Bug fixes
  * DataSet objects (de)serialization: fixed HDF5 reader/writer for FilesOpenItem and FloatArrayItem serialize/deserialize methods
  * Fixed DataSet userconfig read/write test
  * StringItem/ColorItem: fixed unicode/str issues in deserialization methods
  * Added support for strings encoded in file system charset to avoid an error like "String %%r is not UTF-8 encoded" when trying to set an item to a string value (path) obtained with a file system command
  * configtools/image paths: handling file system encoded paths
  * (Issue 14) Restored compatiblity with PyQt v4.4
- Update to 1.5.0
  * Bug fixes
  * Fixed 'callback' property related issue: when updating a !DataSetShowGroupBox or
    !DataSetEditGroupBox internal dataset, the callback property was causing a reset
    of the data items to their default values
  * Possible API compatibility issues
  * datatypes.!OperatorProperty was renamed to !FuncProp
  * Other
  * New features
  * Added test for the !FuncProp item property: how to change an item active state depending on another item's value
  * Added support for dictionaries for `update_dataset` and `restore_dataset` (functions of `guidata.utils`):
  * `update_dataset` may update the destination dataset from a source dictionary
  * `restore_dataset` may update the destination dictionary from a source dataset
  * FloatArrayItem: added option "large" to show all the array values in read-only mode
  * Added new guidata svg logo
  * disthelpers:
  * added support for PySide
  * disthelpers: new function 'get_visual_studio_dlls' -- returns the list of Visual
  * Studio DLLs (and create manifest) associated to Python architecture and version
- Update to 1.4.2
  * Bug fixes
  * disthelpers:
  * the vs2008 option was accidently turned off by default on Windows platforms
  * build_chm.bat: added support for Windows x64
  * Other
  * dataset.qtwidgets:
  * !QLabel widgets word wrapping is now disabled for read-only items and may be disabled for dataset comments: this is necessary because when the parent widget height is constrained, Qt is unexpectedly reducing the height of word-wrapped QLabel widgets below their minimum size, hence truncating their contents...
  * disthelpers:
  * raising an exception when the right version of Ms Visual C++ DLLs was not found
  * now creating the manifest and distributing from the redistribuable package installed in WinSxS
* Tue Aug  7 2012 toddrme2178@gmail.com
- Initial version
